@@ -15,6 +15,29 @@ let ( min ) = `Should_refer_to_runtime_lib
 let ( equal ) = `Should_refer_to_runtime_lib
 let ( compare ) = `Should_refer_to_runtime_lib
 
+module type M1_sig = sig
+  type t [@@deriving_inline compare, equal]
+
+  include
+    sig
+      [@@@ocaml.warning "-32"]
+      include Ppx_compare_lib.Comparable.S with type  t :=  t
+      include Ppx_compare_lib.Equal.S with type  t :=  t
+    end[@@ocaml.doc "@inline"]
+  [@@@end]
+end
+
+module type M1_sig_wrong_name = sig
+  type t1 [@@deriving_inline compare, equal]
+  include
+    sig
+      [@@@ocaml.warning "-32"]
+      val compare_t1 : t1 -> t1 -> int
+      val equal_t1 : t1 -> t1 -> bool
+    end[@@ocaml.doc "@inline"]
+  [@@@end]
+end
+
 module M1 = struct type t = unit [@@deriving compare, equal] end
 
 module M2 = struct type t = int [@@deriving compare, equal] end
@@ -75,6 +98,18 @@ module M24 = struct type t = int * string * [`Foo | `Bar ] [@@deriving compare,
 
 module M25 = struct type t = String.t [@@deriving compare, equal] end
 
+module type M26_sig = sig
+  type 'a t [@@deriving_inline compare, equal]
+
+  include
+    sig
+      [@@@ocaml.warning "-32"]
+      include Ppx_compare_lib.Comparable.S1 with type 'a t :=  'a t
+      include Ppx_compare_lib.Equal.S1 with type 'a t :=  'a t
+    end[@@ocaml.doc "@inline"]
+  [@@@end]
+end
+
 module M26 = struct type 'a t = 'a array [@@deriving compare, equal] end
 
 module MyList = struct type 'a t = Nil | Node of 'a * 'a t [@@deriving compare, equal] end
@@ -111,6 +146,39 @@ module M30 = struct
   [@@deriving compare, equal]
 end
 
+module type Polyrec_sig = sig
+  type ('a, 'b) t = T of ('a option, 'b) t [@@deriving_inline compare, equal]
+
+  include
+    sig
+      [@@@ocaml.warning "-32"]
+      include Ppx_compare_lib.Comparable.S2 with type ('a,'b) t :=  ('a, 'b) t
+      include Ppx_compare_lib.Equal.S2 with type ('a,'b) t :=  ('a, 'b) t
+    end[@@ocaml.doc "@inline"]
+  [@@@end]
+
+  type ('a, 'b) t1 = T of ('a option, 'b) t2
+  and ('a, 'b) t2 = T1 of ('a list, 'b) t1 | T2 of ('a, 'b list) t2
+  [@@deriving_inline compare, equal]
+
+  include
+    sig
+      [@@@ocaml.warning "-32"]
+      val compare_t1 :
+        ('a -> 'a -> int) ->
+        ('b -> 'b -> int) -> ('a, 'b) t1 -> ('a, 'b) t1 -> int
+      val compare_t2 :
+        ('a -> 'a -> int) ->
+        ('b -> 'b -> int) -> ('a, 'b) t2 -> ('a, 'b) t2 -> int
+      val equal_t1 :
+        ('a -> 'a -> bool) ->
+        ('b -> 'b -> bool) -> ('a, 'b) t1 -> ('a, 'b) t1 -> bool
+      val equal_t2 :
+        ('a -> 'a -> bool) ->
+        ('b -> 'b -> bool) -> ('a, 'b) t2 -> ('a, 'b) t2 -> bool
+    end[@@ocaml.doc "@inline"]
+  [@@@end]
+end
 
 module Polyrec = struct
   type ('a, 'b) t = T of ('a option, 'b) t [@@deriving compare, equal]
@@ -198,30 +266,30 @@ module Ignoring_field = struct
     }
   [@@deriving_inline compare, equal]
 
-  
-let _ = fun (_ : t) -> ()
-  
-  
-let compare =
-  (fun a__589_ ->
-     fun b__590_ ->
-       if Ppx_compare_lib.phys_equal a__589_ b__590_
-       then 0
-       else
-         (match compare_int a__589_.b b__590_.b with
-          | 0 -> compare_int a__589_.c b__590_.c
-          | n -> n) : t -> t -> int)
-let _ = compare
-let equal =
-  (fun a__591_ ->
-     fun b__592_ ->
-       if Ppx_compare_lib.phys_equal a__591_ b__592_
-       then true
-       else
-         Ppx_compare_lib.(&&) (equal_int a__591_.b b__592_.b)
-           (equal_int a__591_.c b__592_.c) : t -> t -> bool)
-let _ = equal
-[@@@deriving.end]
+
+  let _ = fun (_ : t) -> ()
+
+
+  let compare =
+    (fun a__589_ ->
+       fun b__590_ ->
+         if Ppx_compare_lib.phys_equal a__589_ b__590_
+         then 0
+         else
+           (match compare_int a__589_.b b__590_.b with
+            | 0 -> compare_int a__589_.c b__590_.c
+            | n -> n) : t -> t -> int)
+  let _ = compare
+  let equal =
+    (fun a__591_ ->
+       fun b__592_ ->
+         if Ppx_compare_lib.phys_equal a__591_ b__592_
+         then true
+         else
+           Ppx_compare_lib.(&&) (equal_int a__591_.b b__592_.b)
+             (equal_int a__591_.c b__592_.c) : t -> t -> bool)
+  let _ = equal
+  [@@@deriving.end]
 
   let equal = [%compare.equal: t]
 end
@@ -245,36 +313,36 @@ module Ignoring = struct
   type t = { a : (int [@ignore]) * string }
   [@@deriving_inline compare, equal]
 
-  
-let _ = fun (_ : t) -> ()
-  
-let compare =
-  (fun a__609_ ->
-     fun b__610_ ->
-       if Ppx_compare_lib.phys_equal a__609_ b__610_
-       then 0
-       else
-         (let (t__611_, t__612_) = a__609_.a in
-          let (t__613_, t__614_) = b__610_.a in
-          match let (_ : _) = t__611_
-                and (_ : _) = t__613_ in 0 with
-          | 0 -> compare_string t__612_ t__614_
-          | n -> n) : t -> t -> int)
-let _ = compare
-let equal =
-  (fun a__615_ ->
-     fun b__616_ ->
-       if Ppx_compare_lib.phys_equal a__615_ b__616_
-       then true
-       else
-         (let (t__617_, t__618_) = a__615_.a in
-          let (t__619_, t__620_) = b__616_.a in
-          Ppx_compare_lib.(&&)
-            (let (_ : _) = t__617_
-             and (_ : _) = t__619_ in true) (equal_string t__618_ t__620_)) :
-  t -> t -> bool)
-let _ = equal
-[@@@deriving.end]
+
+  let _ = fun (_ : t) -> ()
+
+  let compare =
+    (fun a__609_ ->
+       fun b__610_ ->
+         if Ppx_compare_lib.phys_equal a__609_ b__610_
+         then 0
+         else
+           (let (t__611_, t__612_) = a__609_.a in
+            let (t__613_, t__614_) = b__610_.a in
+            match let (_ : _) = t__611_
+              and (_ : _) = t__613_ in 0 with
+            | 0 -> compare_string t__612_ t__614_
+            | n -> n) : t -> t -> int)
+  let _ = compare
+  let equal =
+    (fun a__615_ ->
+       fun b__616_ ->
+         if Ppx_compare_lib.phys_equal a__615_ b__616_
+         then true
+         else
+           (let (t__617_, t__618_) = a__615_.a in
+            let (t__619_, t__620_) = b__616_.a in
+            Ppx_compare_lib.(&&)
+              (let (_ : _) = t__617_
+               and (_ : _) = t__619_ in true) (equal_string t__618_ t__620_)) :
+             t -> t -> bool)
+  let _ = equal
+  [@@@deriving.end]
 
   let%test _ = equal { a = (1, "hi") } { a = (2, "hi") }
   let%test _ = not (equal { a = (1, "hi") } { a = (1, "ho") })
@@ -286,21 +354,21 @@ module Ignoring_with_type = struct
     ; b : (int[@compare.ignore])
     }
   [@@deriving_inline compare]
-  
-let _ = fun (_ : t) -> ()
-  
-let compare =
-  (fun a__621_ ->
-     fun b__622_ ->
-       if Ppx_compare_lib.phys_equal a__621_ b__622_
-       then 0
-       else
-         (match compare_int a__621_.a b__622_.a with
-          | 0 -> let (_ : _) = a__621_.b
-                 and (_ : _) = b__622_.b in 0
-          | n -> n) : t -> t -> int)
-let _ = compare
-[@@@deriving.end]
+
+  let _ = fun (_ : t) -> ()
+
+  let compare =
+    (fun a__621_ ->
+       fun b__622_ ->
+         if Ppx_compare_lib.phys_equal a__621_ b__622_
+         then 0
+         else
+           (match compare_int a__621_.a b__622_.a with
+            | 0 -> let (_ : _) = a__621_.b
+              and (_ : _) = b__622_.b in 0
+            | n -> n) : t -> t -> int)
+  let _ = compare
+  [@@@deriving.end]
 end
 
 module Enum_optim = struct
@@ -308,15 +376,15 @@ module Enum_optim = struct
   type t = A | B | C
   [@@deriving_inline compare, equal]
 
-  
-let _ = fun (_ : t) -> ()
-  
-  
-let compare = (Ppx_compare_lib.polymorphic_compare : t -> t -> int)
-let _ = compare
-let equal = (Ppx_compare_lib.polymorphic_equal : t -> t -> bool)
-let _ = equal
-[@@@deriving.end]
+
+  let _ = fun (_ : t) -> ()
+
+
+  let compare = (Ppx_compare_lib.polymorphic_compare : t -> t -> int)
+  let _ = compare
+  let equal = (Ppx_compare_lib.polymorphic_equal : t -> t -> bool)
+  let _ = equal
+  [@@@deriving.end]
 end
 
 
